@@ -36,7 +36,7 @@ from xonsh.tools import (
     is_logfile_opt, to_logfile_opt, logfile_opt_to_str, executables_in,
     is_nonstring_seq_of_strings, pathsep_to_upper_seq,
     seq_to_upper_pathsep, print_color, is_history_backend, to_itself,
-    swap_values,
+    swap_values, ptk2_color_depth_setter
 )
 import xonsh.prompt.base as prompt
 
@@ -157,6 +157,7 @@ def DEFAULT_ENSURERS():
                 seq_to_upper_pathsep),
     'PRETTY_PRINT_RESULTS': (is_bool, to_bool, bool_to_str),
     'PROMPT': (is_string_or_callable, ensure_string, ensure_string),
+    'PROMPT_TOOLKIT_COLOR_DEPTH': (always_false, ptk2_color_depth_setter, ensure_string),
     'PUSHD_MINUS': (is_bool, to_bool, bool_to_str),
     'PUSHD_SILENT': (is_bool, to_bool, bool_to_str),
     'RAISE_SUBPROC_ERROR': (is_bool, to_bool, bool_to_str),
@@ -274,7 +275,7 @@ def DEFAULT_VALUES():
         'AUTO_CD': False,
         'AUTO_PUSHD': False,
         'AUTO_SUGGEST': True,
-        'AUTO_SUGGEST_IN_COMPLETIONS': True,
+        'AUTO_SUGGEST_IN_COMPLETIONS': False,
         'BASH_COMPLETIONS': BASH_COMPLETIONS_DEFAULT,
         'CASE_SENSITIVE_COMPLETIONS': ON_LINUX,
         'CDPATH': (),
@@ -311,6 +312,7 @@ def DEFAULT_VALUES():
         'PATHEXT': ['.COM', '.EXE', '.BAT', '.CMD'] if ON_WINDOWS else [],
         'PRETTY_PRINT_RESULTS': True,
         'PROMPT': prompt.default_prompt(),
+        'PROMPT_TOOLKIT_COLOR_DEPTH': '',
         'PUSHD_MINUS': False,
         'PUSHD_SILENT': False,
         'RAISE_SUBPROC_ERROR': False,
@@ -542,6 +544,10 @@ def DEFAULT_DOCS():
         'http://xon.sh/tutorial.html#customizing-the-prompt. '
         'This value is never inherited from parent processes.',
         default='``xonsh.environ.DEFAULT_PROMPT``'),
+    'PROMPT_TOOLKIT_COLOR_DEPTH': VarDocs(
+        'The color depth used by prompt toolkit 2. Possible values are: '
+        '``DEPTH_1_BIT``, ``DEPTH_4_BIT``, ``DEPTH_8_BIT``, ``DEPTH_24_BIT`` '
+        'colors. Default is an empty string which means that prompt toolkit decide.'),
     'PUSHD_MINUS': VarDocs(
         'Flag for directory pushing functionality. False is the normal '
         'behavior.'),
@@ -813,12 +819,6 @@ class Env(cabc.MutableMapping):
             self._d['PATH'] = list(PATH_DEFAULT)
         self._detyped = None
 
-    @property
-    def arg_regex(self):
-        if self._arg_regex is None:
-            self._arg_regex = re.compile(r'ARG(\d+)')
-        return self._arg_regex
-
     @staticmethod
     def detypeable(val):
         return not (callable(val) or isinstance(val, cabc.MutableMapping))
@@ -937,14 +937,6 @@ class Env(cabc.MutableMapping):
             return self['PROMPT_FIELDS']
         if key is Ellipsis:
             return self
-        m = self.arg_regex.match(key)
-        if (m is not None) and (key not in self._d) and ('ARGS' in self._d):
-            args = self._d['ARGS']
-            ix = int(m.group(1))
-            if ix >= len(args):
-                e = "Not enough arguments given to access ARG{0}."
-                raise KeyError(e.format(ix))
-            val = self._d['ARGS'][ix]
         elif key in self._d:
             val = self._d[key]
         elif key in self._defaults:
@@ -1128,3 +1120,14 @@ def default_env(env=None):
     if env is not None:
         ctx.update(env)
     return ctx
+
+
+def make_args_env(args=None):
+    """Makes a dictionary containing the $ARGS and $ARG<N> environment
+    variables. If the supplied ARGS is None, then sys.argv is used.
+    """
+    if args is None:
+        args = sys.argv
+    env = {'ARG' + str(i): arg for i, arg in enumerate(args)}
+    env['ARGS'] = list(args)  # make a copy so we don't interfere with original variable
+    return env
