@@ -1,6 +1,7 @@
 """Xonsh color styling tools that simulate pygments, when it is unavailable."""
 import builtins
 import string
+from collections import defaultdict
 
 from xonsh.platform import HAS_PYGMENTS
 from xonsh.lazyasd import LazyObject
@@ -252,172 +253,172 @@ KNOWN_COLORS = LazyObject(lambda: frozenset([
     'YELLOW',
 ]), globals(), 'KNOWN_COLORS')
 
-DEFAULT_STYLE_DICT = LazyObject(lambda: {
+DEFAULT_STYLE_DICT = LazyObject(lambda: defaultdict(lambda: '', {
     Token: '',
-    Token.Aborted: '#ansidarkgray',
-    Token.AutoSuggestion: '#ansidarkgray',
-    Token.Color.BACKGROUND_BLACK: 'bg:#ansiblack',
-    Token.Color.BACKGROUND_BLUE: 'bg:#ansidarkblue',
-    Token.Color.BACKGROUND_CYAN: 'bg:#ansiteal',
-    Token.Color.BACKGROUND_GREEN: 'bg:#ansidarkgreen',
-    Token.Color.BACKGROUND_INTENSE_BLACK: 'bg:#ansidarkgray',
-    Token.Color.BACKGROUND_INTENSE_BLUE: 'bg:#ansiblue',
-    Token.Color.BACKGROUND_INTENSE_CYAN: 'bg:#ansiturquoise',
-    Token.Color.BACKGROUND_INTENSE_GREEN: 'bg:#ansigreen',
-    Token.Color.BACKGROUND_INTENSE_PURPLE: 'bg:#ansifuchsia',
-    Token.Color.BACKGROUND_INTENSE_RED: 'bg:#ansired',
-    Token.Color.BACKGROUND_INTENSE_WHITE: 'bg:#ansiwhite',
-    Token.Color.BACKGROUND_INTENSE_YELLOW: 'bg:#ansiyellow',
-    Token.Color.BACKGROUND_PURPLE: 'bg:#ansipurple',
-    Token.Color.BACKGROUND_RED: 'bg:#ansidarkred',
-    Token.Color.BACKGROUND_WHITE: 'bg:#ansilightgray',
-    Token.Color.BACKGROUND_YELLOW: 'bg:#ansibrown',
-    Token.Color.BLACK: '#ansiblack',
-    Token.Color.BLUE: '#ansidarkblue',
-    Token.Color.BOLD_BLACK: 'bold #ansiblack',
-    Token.Color.BOLD_BLUE: 'bold #ansidarkblue',
-    Token.Color.BOLD_CYAN: 'bold #ansiteal',
-    Token.Color.BOLD_GREEN: 'bold #ansidarkgreen',
-    Token.Color.BOLD_INTENSE_BLACK: 'bold #ansidarkgray',
-    Token.Color.BOLD_INTENSE_BLUE: 'bold #ansiblue',
-    Token.Color.BOLD_INTENSE_CYAN: 'bold #ansiturquoise',
-    Token.Color.BOLD_INTENSE_GREEN: 'bold #ansigreen',
-    Token.Color.BOLD_INTENSE_PURPLE: 'bold #ansifuchsia',
-    Token.Color.BOLD_INTENSE_RED: 'bold #ansired',
-    Token.Color.BOLD_INTENSE_WHITE: 'bold #ansiwhite',
-    Token.Color.BOLD_INTENSE_YELLOW: 'bold #ansiyellow',
-    Token.Color.BOLD_PURPLE: 'bold #ansipurple',
-    Token.Color.BOLD_RED: 'bold #ansidarkred',
-    Token.Color.BOLD_UNDERLINE_BLACK: 'bold underline #ansiblack',
-    Token.Color.BOLD_UNDERLINE_BLUE: 'bold underline #ansidarkblue',
-    Token.Color.BOLD_UNDERLINE_CYAN: 'bold underline #ansiteal',
-    Token.Color.BOLD_UNDERLINE_GREEN: 'bold underline #ansidarkgreen',
-    Token.Color.BOLD_UNDERLINE_INTENSE_BLACK: 'bold underline #ansidarkgray',
-    Token.Color.BOLD_UNDERLINE_INTENSE_BLUE: 'bold underline #ansiblue',
-    Token.Color.BOLD_UNDERLINE_INTENSE_CYAN: 'bold underline #ansiturquoise',
-    Token.Color.BOLD_UNDERLINE_INTENSE_GREEN: 'bold underline #ansigreen',
-    Token.Color.BOLD_UNDERLINE_INTENSE_PURPLE: 'bold underline #ansifuchsia',
-    Token.Color.BOLD_UNDERLINE_INTENSE_RED: 'bold underline #ansired',
-    Token.Color.BOLD_UNDERLINE_INTENSE_WHITE: 'bold underline #ansiwhite',
-    Token.Color.BOLD_UNDERLINE_INTENSE_YELLOW: 'bold underline #ansiyellow',
-    Token.Color.BOLD_UNDERLINE_PURPLE: 'bold underline #ansipurple',
-    Token.Color.BOLD_UNDERLINE_RED: 'bold underline #ansidarkred',
-    Token.Color.BOLD_UNDERLINE_WHITE: 'bold underline #ansilightgray',
-    Token.Color.BOLD_UNDERLINE_YELLOW: 'bold underline #ansibrown',
-    Token.Color.BOLD_WHITE: 'bold #ansilightgray',
-    Token.Color.BOLD_YELLOW: 'bold #ansibrown',
-    Token.Color.CYAN: '#ansiteal',
-    Token.Color.GREEN: '#ansidarkgreen',
-    Token.Color.INTENSE_BLACK: '#ansidarkgray',
-    Token.Color.INTENSE_BLUE: '#ansiblue',
-    Token.Color.INTENSE_CYAN: '#ansiturquoise',
-    Token.Color.INTENSE_GREEN: '#ansigreen',
-    Token.Color.INTENSE_PURPLE: '#ansifuchsia',
-    Token.Color.INTENSE_RED: '#ansired',
-    Token.Color.INTENSE_WHITE: '#ansiwhite',
-    Token.Color.INTENSE_YELLOW: '#ansiyellow',
+    Token.Aborted: 'ansibrightblack',
+    Token.AutoSuggestion: 'ansibrightblack',
+    Token.Color.BACKGROUND_BLACK: 'bg:ansiblack',
+    Token.Color.BACKGROUND_BLUE: 'bg:ansiblue',
+    Token.Color.BACKGROUND_CYAN: 'bg:ansicyan',
+    Token.Color.BACKGROUND_GREEN: 'bg:ansigreen',
+    Token.Color.BACKGROUND_INTENSE_BLACK: 'bg:ansibrightblack',
+    Token.Color.BACKGROUND_INTENSE_BLUE: 'bg:ansibrightblue',
+    Token.Color.BACKGROUND_INTENSE_CYAN: 'bg:ansibrightcyan',
+    Token.Color.BACKGROUND_INTENSE_GREEN: 'bg:ansibrightgreen',
+    Token.Color.BACKGROUND_INTENSE_PURPLE: 'bg:ansibrightmagenta',
+    Token.Color.BACKGROUND_INTENSE_RED: 'bg:ansibrightred',
+    Token.Color.BACKGROUND_INTENSE_WHITE: 'bg:ansiwhite',
+    Token.Color.BACKGROUND_INTENSE_YELLOW: 'bg:ansibrightyellow',
+    Token.Color.BACKGROUND_PURPLE: 'bg:ansimagenta',
+    Token.Color.BACKGROUND_RED: 'bg:ansired',
+    Token.Color.BACKGROUND_WHITE: 'bg:ansigray',
+    Token.Color.BACKGROUND_YELLOW: 'bg:ansiyellow',
+    Token.Color.BLACK: 'ansiblack',
+    Token.Color.BLUE: 'ansiblue',
+    Token.Color.BOLD_BLACK: 'bold ansiblack',
+    Token.Color.BOLD_BLUE: 'bold ansiblue',
+    Token.Color.BOLD_CYAN: 'bold ansicyan',
+    Token.Color.BOLD_GREEN: 'bold ansigreen',
+    Token.Color.BOLD_INTENSE_BLACK: 'bold ansibrightblack',
+    Token.Color.BOLD_INTENSE_BLUE: 'bold ansibrightblue',
+    Token.Color.BOLD_INTENSE_CYAN: 'bold ansibrightcyan',
+    Token.Color.BOLD_INTENSE_GREEN: 'bold ansibrightgreen',
+    Token.Color.BOLD_INTENSE_PURPLE: 'bold ansibrightmagenta',
+    Token.Color.BOLD_INTENSE_RED: 'bold ansibrightred',
+    Token.Color.BOLD_INTENSE_WHITE: 'bold ansiwhite',
+    Token.Color.BOLD_INTENSE_YELLOW: 'bold ansibrightyellow',
+    Token.Color.BOLD_PURPLE: 'bold ansimagenta',
+    Token.Color.BOLD_RED: 'bold ansired',
+    Token.Color.BOLD_UNDERLINE_BLACK: 'bold underline ansiblack',
+    Token.Color.BOLD_UNDERLINE_BLUE: 'bold underline ansiblue',
+    Token.Color.BOLD_UNDERLINE_CYAN: 'bold underline ansicyan',
+    Token.Color.BOLD_UNDERLINE_GREEN: 'bold underline ansigreen',
+    Token.Color.BOLD_UNDERLINE_INTENSE_BLACK: 'bold underline ansibrightblack',
+    Token.Color.BOLD_UNDERLINE_INTENSE_BLUE: 'bold underline ansibrightblue',
+    Token.Color.BOLD_UNDERLINE_INTENSE_CYAN: 'bold underline ansibrightcyan',
+    Token.Color.BOLD_UNDERLINE_INTENSE_GREEN: 'bold underline ansibrightgreen',
+    Token.Color.BOLD_UNDERLINE_INTENSE_PURPLE: 'bold underline ansibrightmagenta',
+    Token.Color.BOLD_UNDERLINE_INTENSE_RED: 'bold underline ansibrightred',
+    Token.Color.BOLD_UNDERLINE_INTENSE_WHITE: 'bold underline ansiwhite',
+    Token.Color.BOLD_UNDERLINE_INTENSE_YELLOW: 'bold underline ansibrightyellow',
+    Token.Color.BOLD_UNDERLINE_PURPLE: 'bold underline ansimagenta',
+    Token.Color.BOLD_UNDERLINE_RED: 'bold underline ansired',
+    Token.Color.BOLD_UNDERLINE_WHITE: 'bold underline ansigray',
+    Token.Color.BOLD_UNDERLINE_YELLOW: 'bold underline ansiyellow',
+    Token.Color.BOLD_WHITE: 'bold ansigray',
+    Token.Color.BOLD_YELLOW: 'bold ansiyellow',
+    Token.Color.CYAN: 'ansicyan',
+    Token.Color.GREEN: 'ansigreen',
+    Token.Color.INTENSE_BLACK: 'ansibrightblack',
+    Token.Color.INTENSE_BLUE: 'ansibrightblue',
+    Token.Color.INTENSE_CYAN: 'ansibrightcyan',
+    Token.Color.INTENSE_GREEN: 'ansibrightgreen',
+    Token.Color.INTENSE_PURPLE: 'ansibrightmagenta',
+    Token.Color.INTENSE_RED: 'ansibrightred',
+    Token.Color.INTENSE_WHITE: 'ansiwhite',
+    Token.Color.INTENSE_YELLOW: 'ansibrightyellow',
     Token.Color.NO_COLOR: 'noinherit',
-    Token.Color.PURPLE: '#ansipurple',
-    Token.Color.RED: '#ansidarkred',
-    Token.Color.UNDERLINE_BLACK: 'underline #ansiblack',
-    Token.Color.UNDERLINE_BLUE: 'underline #ansidarkblue',
-    Token.Color.UNDERLINE_CYAN: 'underline #ansiteal',
-    Token.Color.UNDERLINE_GREEN: 'underline #ansidarkgreen',
-    Token.Color.UNDERLINE_INTENSE_BLACK: 'underline #ansidarkgray',
-    Token.Color.UNDERLINE_INTENSE_BLUE: 'underline #ansiblue',
-    Token.Color.UNDERLINE_INTENSE_CYAN: 'underline #ansiturquoise',
-    Token.Color.UNDERLINE_INTENSE_GREEN: 'underline #ansigreen',
-    Token.Color.UNDERLINE_INTENSE_PURPLE: 'underline #ansifuchsia',
-    Token.Color.UNDERLINE_INTENSE_RED: 'underline #ansired',
-    Token.Color.UNDERLINE_INTENSE_WHITE: 'underline #ansiwhite',
-    Token.Color.UNDERLINE_INTENSE_YELLOW: 'underline #ansiyellow',
-    Token.Color.UNDERLINE_PURPLE: 'underline #ansipurple',
-    Token.Color.UNDERLINE_RED: 'underline #ansidarkred',
-    Token.Color.UNDERLINE_WHITE: 'underline #ansilightgray',
-    Token.Color.UNDERLINE_YELLOW: 'underline #ansibrown',
-    Token.Color.WHITE: '#ansilightgray',
-    Token.Color.YELLOW: '#ansibrown',
-    Token.Comment: 'underline #ansiteal',
+    Token.Color.PURPLE: 'ansimagenta',
+    Token.Color.RED: 'ansired',
+    Token.Color.UNDERLINE_BLACK: 'underline ansiblack',
+    Token.Color.UNDERLINE_BLUE: 'underline ansiblue',
+    Token.Color.UNDERLINE_CYAN: 'underline ansicyan',
+    Token.Color.UNDERLINE_GREEN: 'underline ansigreen',
+    Token.Color.UNDERLINE_INTENSE_BLACK: 'underline ansibrightblack',
+    Token.Color.UNDERLINE_INTENSE_BLUE: 'underline ansibrightblue',
+    Token.Color.UNDERLINE_INTENSE_CYAN: 'underline ansibrightcyan',
+    Token.Color.UNDERLINE_INTENSE_GREEN: 'underline ansibrightgreen',
+    Token.Color.UNDERLINE_INTENSE_PURPLE: 'underline ansibrightmagenta',
+    Token.Color.UNDERLINE_INTENSE_RED: 'underline ansibrightred',
+    Token.Color.UNDERLINE_INTENSE_WHITE: 'underline ansiwhite',
+    Token.Color.UNDERLINE_INTENSE_YELLOW: 'underline ansibrightyellow',
+    Token.Color.UNDERLINE_PURPLE: 'underline ansimagenta',
+    Token.Color.UNDERLINE_RED: 'underline ansired',
+    Token.Color.UNDERLINE_WHITE: 'underline ansigray',
+    Token.Color.UNDERLINE_YELLOW: 'underline ansiyellow',
+    Token.Color.WHITE: 'ansigray',
+    Token.Color.YELLOW: 'ansiyellow',
+    Token.Comment: 'underline ansicyan',
     Token.Comment.Hashbang: '',
     Token.Comment.Multiline: '',
-    Token.Comment.Preproc: 'underline #ansibrown',
+    Token.Comment.Preproc: 'underline ansiyellow',
     Token.Comment.PreprocFile: '',
     Token.Comment.Single: '',
     Token.Comment.Special: '',
-    Token.Error: '#ansired',
+    Token.Error: 'ansibrightred',
     Token.Escape: '',
     Token.Generic: '',
-    Token.Generic.Deleted: '#ansidarkred',
+    Token.Generic.Deleted: 'ansired',
     Token.Generic.Emph: 'underline',
-    Token.Generic.Error: 'bold #ansired',
-    Token.Generic.Heading: 'bold #ansidarkblue',
-    Token.Generic.Inserted: '#ansigreen',
-    Token.Generic.Output: '#ansidarkblue',
-    Token.Generic.Prompt: 'bold #ansidarkblue',
+    Token.Generic.Error: 'bold ansibrightred',
+    Token.Generic.Heading: 'bold ansiblue',
+    Token.Generic.Inserted: 'ansibrightgreen',
+    Token.Generic.Output: 'ansiblue',
+    Token.Generic.Prompt: 'bold ansiblue',
     Token.Generic.Strong: '',
-    Token.Generic.Subheading: 'bold #ansipurple',
-    Token.Generic.Traceback: '#ansidarkblue',
-    Token.Keyword: 'bold #ansidarkgreen',
+    Token.Generic.Subheading: 'bold ansimagenta',
+    Token.Generic.Traceback: 'ansiblue',
+    Token.Keyword: 'bold ansigreen',
     Token.Keyword.Constant: '',
     Token.Keyword.Declaration: '',
     Token.Keyword.Namespace: '',
     Token.Keyword.Pseudo: 'nobold',
     Token.Keyword.Reserved: '',
-    Token.Keyword.Type: 'nobold #ansidarkred',
+    Token.Keyword.Type: 'nobold ansired',
     Token.Literal: '',
     Token.Literal.Date: '',
-    Token.Literal.Number: '#ansidarkgray',
+    Token.Literal.Number: 'ansibrightblack',
     Token.Literal.Number.Bin: '',
     Token.Literal.Number.Float: '',
     Token.Literal.Number.Hex: '',
     Token.Literal.Number.Integer: '',
     Token.Literal.Number.Integer.Long: '',
     Token.Literal.Number.Oct: '',
-    Token.Literal.String: '#ansired',
+    Token.Literal.String: 'ansibrightred',
     Token.Literal.String.Affix: '',
     Token.Literal.String.Backtick: '',
     Token.Literal.String.Char: '',
     Token.Literal.String.Delimiter: '',
     Token.Literal.String.Doc: 'underline',
     Token.Literal.String.Double: '',
-    Token.Literal.String.Escape: 'bold #ansibrown',
+    Token.Literal.String.Escape: 'bold ansiyellow',
     Token.Literal.String.Heredoc: '',
-    Token.Literal.String.Interpol: 'bold #ansipurple',
-    Token.Literal.String.Other: '#ansidarkgreen',
-    Token.Literal.String.Regex: '#ansipurple',
+    Token.Literal.String.Interpol: 'bold ansimagenta',
+    Token.Literal.String.Other: 'ansigreen',
+    Token.Literal.String.Regex: 'ansimagenta',
     Token.Literal.String.Single: '',
-    Token.Literal.String.Symbol: '#ansibrown',
-    Token.Menu.Completions: 'bg:#ansilightgray #ansiblack',
+    Token.Literal.String.Symbol: 'ansiyellow',
+    Token.Menu.Completions: 'bg:ansigray ansiblack',
     Token.Menu.Completions.Completion: '',
-    Token.Menu.Completions.Completion.Current: 'bg:#ansidarkgray #ansiwhite',
+    Token.Menu.Completions.Completion.Current: 'bg:ansibrightblack ansiwhite',
     Token.Name: '',
-    Token.Name.Attribute: '#ansiyellow',
-    Token.Name.Builtin: '#ansidarkgreen',
+    Token.Name.Attribute: 'ansibrightyellow',
+    Token.Name.Builtin: 'ansigreen',
     Token.Name.Builtin.Pseudo: '',
-    Token.Name.Class: 'bold #ansiblue',
-    Token.Name.Constant: '#ansidarkred',
-    Token.Name.Decorator: '#ansifuchsia',
-    Token.Name.Entity: 'bold #ansilightgray',
-    Token.Name.Exception: 'bold #ansired',
-    Token.Name.Function: '#ansiblue',
+    Token.Name.Class: 'bold ansibrightblue',
+    Token.Name.Constant: 'ansired',
+    Token.Name.Decorator: 'ansibrightmagenta',
+    Token.Name.Entity: 'bold ansigray',
+    Token.Name.Exception: 'bold ansibrightred',
+    Token.Name.Function: 'ansibrightblue',
     Token.Name.Function.Magic: '',
-    Token.Name.Label: '#ansiyellow',
-    Token.Name.Namespace: 'bold #ansiblue',
+    Token.Name.Label: 'ansibrightyellow',
+    Token.Name.Namespace: 'bold ansibrightblue',
     Token.Name.Other: '',
     Token.Name.Property: '',
-    Token.Name.Tag: 'bold #ansidarkgreen',
-    Token.Name.Variable: '#ansidarkblue',
+    Token.Name.Tag: 'bold ansigreen',
+    Token.Name.Variable: 'ansiblue',
     Token.Name.Variable.Class: '',
     Token.Name.Variable.Global: '',
     Token.Name.Variable.Instance: '',
     Token.Name.Variable.Magic: '',
-    Token.Operator: '#ansidarkgray',
-    Token.Operator.Word: 'bold #ansipurple',
+    Token.Operator: 'ansibrightblack',
+    Token.Operator.Word: 'bold ansimagenta',
     Token.Other: '',
     Token.Punctuation: '',
-    Token.Scrollbar: 'bg:#ansidarkgray',
-    Token.Scrollbar.Arrow: 'bg:#ansiblack #ansiwhite bold',
-    Token.Scrollbar.Button: 'bg:#ansiblack',
+    Token.Scrollbar: 'bg:ansibrightblack',
+    Token.Scrollbar.Arrow: 'bg:ansiblack ansiwhite bold',
+    Token.Scrollbar.Button: 'bg:ansiblack',
     Token.Text: '',
-    Token.Text.Whitespace: '#ansilightgray',
-}, globals(), 'DEFAULT_STYLE_DICT')
+    Token.Text.Whitespace: 'ansigray',
+}), globals(), 'DEFAULT_STYLE_DICT')
